@@ -1,4 +1,4 @@
-from websockets.sync.server import serve, ServerConnection
+from websockets.sync.server import serve, ServerConnection, Server
 from websockets.exceptions import ConnectionClosedOK
 import requests
 import json
@@ -9,7 +9,7 @@ from .backend import uploadOrder
 import logging
 logger = logging.getLogger(__name__)
 
-def listen(host: str, port: int, callback) -> None:
+def listen(host: str, port: int, callback) -> Server:
     '''
     Start a WebSockets server on the specified host and port.
 
@@ -24,7 +24,7 @@ def listen(host: str, port: int, callback) -> None:
 
     Returns
     -------
-    None
+    Server : websockets.sync.server.Server
 
     Notes
     -----
@@ -34,7 +34,15 @@ def listen(host: str, port: int, callback) -> None:
     --------
     websockets.sync.server.serve : The underlying function used to start the server.
     '''
-    return serve(callback, host, port)
+    usePort = port
+    while usePort - port <= 4:
+        try:
+            return serve(callback, host, usePort)
+        except OSError as error:
+            logger.warning(f'Failed to start server ({host}:{usePort}), try using next port number: %s', error)
+        usePort += 1
+
+    raise OSError(f'Failed to start server ({host}:{port}) as all port numbers in range ({port}-{port+5}) are already in use')
 
 def handleConnection(websocket: ServerConnection, project: Project, host: str, thread) -> None:
     '''
